/****************************************************************************
**
** This file is part of a Qt Solutions component.
** 
** Copyright (c) 2009 Nokia Corporation and/or its subsidiary(-ies).
** 
** Contact:  Qt Software Information (qt-info@nokia.com)
** 
** Commercial Usage  
** Licensees holding valid Qt Commercial licenses may use this file in
** accordance with the Qt Solutions Commercial License Agreement provided
** with the Software or, alternatively, in accordance with the terms
** contained in a written agreement between you and Nokia.
** 
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
** 
** In addition, as a special exception, Nokia gives you certain
** additional rights. These rights are described in the Nokia Qt LGPL
** Exception version 1.0, included in the file LGPL_EXCEPTION.txt in this
** package.
** 
** GNU General Public License Usage 
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3.0 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU General Public License version 3.0 requirements will be
** met: http://www.gnu.org/copyleft/gpl.html.
** 
** Please note Third Party Software included with Qt Solutions may impose
** additional restrictions and it is the user's responsibility to ensure
** that they have met the licensing requirements of the GPL, LGPL, or Qt
** Solutions Commercial license and the relevant license of the Third
** Party Software they are using.
** 
** If you are unsure which license is appropriate for your use, please
** contact the sales department at qt-sales@nokia.com.
** 
****************************************************************************/



#include "qstate.h"
#include "qstate_p.h"
#include "qsignaltransition.h"

QT_BEGIN_NAMESPACE

/*!
  \class QtState

  \brief The QtState class provides a default state implementation for QtStateMachine.

  

  QtState is part of \l{The State Machine Framework}.

  The setInitialState() function sets the initial state; this is only relevant
  for states that have child states. The child states are mutually exclusive
  states, and the state machine needs to know which child state to enter when
  the parent state is the target of a transition.
*/

QtStatePrivate::QtStatePrivate()
    : initialState(0)
{
}

QtStatePrivate::~QtStatePrivate()
{
}

QtStatePrivate *QtStatePrivate::get(QtState *q)
{
    return q->d_func();
}

const QtStatePrivate *QtStatePrivate::get(const QtState *q)
{
    return q->d_func();
}

/*!
  Constructs a new state with the given \a parent state.
*/
QtState::QtState(QtAbstractStateGroup *parent)
    : QtAbstractStateGroup(*new QtStatePrivate, parent)
{
}

/*!
  \internal
*/
QtState::QtState(QtStatePrivate &dd, QtAbstractStateGroup *parent)
    : QtAbstractStateGroup(dd, parent)
{
}

/*!
  Destroys this state.
*/
QtState::~QtState()
{
}

/*!
  Returns this state's initial state, or 0 if the state has no initial state.
*/
QtAbstractState *QtState::initialState() const
{
    Q_D(const QtState);
    return d->initialState;
}

/*!
  Sets this state's initial state to be the given \a state.
  \a state has to be a child of this state.
*/
void QtState::setInitialState(QtAbstractState *state)
{
    Q_D(QtState);
    if (state && (state->parentState() != this)) {
        qWarning("QtState::setInitialState: state %p is not a child of this state (%p)",
                 state, this);
        return;
    }
    d->initialState = state;
}

/*!
  \reimp
*/
void QtState::onEntry()
{
    QtAbstractStateGroup::onEntry();
}

/*!
  \reimp
*/
void QtState::onExit()
{
    QtAbstractStateGroup::onExit();
}

QT_END_NAMESPACE
